@@ -2,10 +2,10 @@ package Net::CIDR::MobileJP;
 use strict;
 use warnings;
 use Carp;
+use version; our $VERSION = 0.03;
 use YAML;
 use Net::CIDR::Lite;
 use File::ShareDir ();
-our $VERSION = '0.0.9';
 
 sub new {
     my ($class, $stuff) = @_;
@@ -33,7 +33,7 @@ sub _load_config {
     my ($self, $stuff) = @_;
 
     my $data;
-    if (defined $stuff && -f $stuff && -r _) {
+    if (-f $stuff && -r _) {
         # load yaml from file
         $data = YAML::LoadFile($stuff);
     } elsif ($stuff) {
@@ -99,8 +99,6 @@ Carrier name is compatible with L<HTTP::MobileAgent>.
 =head1 THANKS TO
 
   Tatsuhiko Miyagawa
-  Masayoshi Sekimura
-  HIROSE, Masaaki
 
 =head1 SEE ALSO
 
